"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styleSheetToString = styleSheetToString;
exports.insertRule = insertRule;
exports.stylesheet = void 0;

function hasDOM() {
  return typeof document !== 'undefined';
}

function initStyleSheet() {
  var stylesheet;

  if (hasDOM()) {
    stylesheet = document.createElement('style');
    document.head.append(stylesheet);
  } else {
    stylesheet = {
      sheet: {
        cssRules: [],
        insertRule: function insertRule(rule) {
          return stylesheet.sheet.cssRules.push(rule);
        }
      }
    };
  }

  return stylesheet;
}

function styleSheetToString() {
  var rules = Array.from(stylesheet.sheet.cssRules);
  return hasDOM() ? rules.map(function (c) {
    return c.cssText;
  }).filter(Boolean).join(' ') // prettier-ignore
  : rules.join(' ');
}

function insertRule(rule) {
  stylesheet.sheet.insertRule(rule, stylesheet.sheet.cssRules.length);
}

var stylesheet = initStyleSheet();
exports.stylesheet = stylesheet;
//# sourceMappingURL=stylesheet.js.map